@@ -50,7 +50,7 @@ async def get_environment(
     x_connect_environment_id: str = Header(),
 ):
     extension = client('devops').services[x_connect_extension_id]
-    return [
-        variable
+    return {
+        variable['name']: variable['value']
         async for variable in extension.environments[x_connect_environment_id].variables.all()
-    ]
+    }
